[nautilus-actions/file-manager-actions] naxml-ormats is renamed to fma-xml-formats



commit 7a889acbe3ed48b4ab3885716edcdf4de6ee603f
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 17:17:29 2015 +0200

    naxml-ormats is renamed to fma-xml-formats

 src/io-xml/Makefile.am                            |    4 +-
 src/io-xml/{naxml-formats.c => fma-xml-formats.c} |   36 ++++++++++----------
 src/io-xml/{naxml-formats.h => fma-xml-formats.h} |   16 +++++-----
 src/io-xml/naxml-provider.c                       |    6 ++--
 src/io-xml/naxml-writer.c                         |   14 ++++----
 5 files changed, 38 insertions(+), 38 deletions(-)
---
diff --git a/src/io-xml/Makefile.am b/src/io-xml/Makefile.am
index ebd1a51..362aad6 100644
--- a/src/io-xml/Makefile.am
+++ b/src/io-xml/Makefile.am
@@ -46,8 +46,8 @@ libna_io_xml_la_SOURCES = \
        naxml-provider.h                                                                        \
        naxml-keys.c                                                                            \
        naxml-keys.h                                                                            \
-       naxml-formats.c                                                                         \
-       naxml-formats.h                                                                         \
+       fma-xml-formats.c                                                                       \
+       fma-xml-formats.h                                                                       \
        naxml-reader.c                                                                          \
        naxml-reader.h                                                                          \
        naxml-writer.c                                                                          \
diff --git a/src/io-xml/naxml-formats.h b/src/io-xml/fma-xml-formats.h
similarity index 75%
rename from src/io-xml/naxml-formats.h
rename to src/io-xml/fma-xml-formats.h
index e0f08e5..b157a50 100644
--- a/src/io-xml/naxml-formats.h
+++ b/src/io-xml/fma-xml-formats.h
@@ -27,8 +27,8 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __NAXML_FORMATS_H__
-#define __NAXML_FORMATS_H__
+#ifndef __IO_XML_FMA_XML_FORMATS_H__
+#define __IO_XML_FMA_XML_FORMATS_H__
 
 #include <glib.h>
 
@@ -36,13 +36,13 @@
 
 G_BEGIN_DECLS
 
-#define NAXML_FORMAT_GCONF_SCHEMA_V1                   "GConfSchemaV1"
-#define NAXML_FORMAT_GCONF_SCHEMA_V2                   "GConfSchemaV2"
-#define NAXML_FORMAT_GCONF_ENTRY                               "GConfEntry"
+#define FMA_XML_FORMAT_GCONF_SCHEMA_V1                 "GConfSchemaV1"
+#define FMA_XML_FORMAT_GCONF_SCHEMA_V2                 "GConfSchemaV2"
+#define FMA_XML_FORMAT_GCONF_ENTRY                             "GConfEntry"
 
-GList *naxml_formats_get_formats ( const FMAIExporter *exporter );
-void   naxml_formats_free_formats( GList *format_list );
+GList *fma_xml_formats_get_formats ( const FMAIExporter *exporter );
+void   fma_xml_formats_free_formats( GList *format_list );
 
 G_END_DECLS
 
-#endif /* __NAXML_FORMATS_H__ */
+#endif /* __IO_XML_FMA_XML_FORMATS_H__ */
diff --git a/src/io-xml/naxml-provider.c b/src/io-xml/naxml-provider.c
index d23d5b2..ab7125f 100644
--- a/src/io-xml/naxml-provider.c
+++ b/src/io-xml/naxml-provider.c
@@ -36,7 +36,7 @@
 #include <api/fma-iimporter.h>
 
 #include "naxml-provider.h"
-#include "naxml-formats.h"
+#include "fma-xml-formats.h"
 #include "naxml-reader.h"
 #include "naxml-writer.h"
 
@@ -249,13 +249,13 @@ iexporter_get_name( const FMAIExporter *exporter )
 static void *
 iexporter_get_formats( const FMAIExporter *exporter )
 {
-       return(( void * ) naxml_formats_get_formats( exporter ));
+       return(( void * ) fma_xml_formats_get_formats( exporter ));
 }
 
 static void
 iexporter_free_formats( const FMAIExporter *exporter, GList *format_list )
 {
-       naxml_formats_free_formats( format_list );
+       fma_xml_formats_free_formats( format_list );
 }
 
 static void
diff --git a/src/io-xml/naxml-writer.c b/src/io-xml/naxml-writer.c
index dc8c205..45a8b08 100644
--- a/src/io-xml/naxml-writer.c
+++ b/src/io-xml/naxml-writer.c
@@ -44,7 +44,7 @@
 
 #include <io-gconf/fma-gconf-keys.h>
 
-#include "naxml-formats.h"
+#include "fma-xml-formats.h"
 #include "naxml-keys.h"
 #include "naxml-writer.h"
 
@@ -127,7 +127,7 @@ static guint           writer_to_buffer( NAXMLWriter *writer );
 
 static ExportFormatFn st_export_format_fn[] = {
 
-       { NAXML_FORMAT_GCONF_SCHEMA_V1,
+       { FMA_XML_FORMAT_GCONF_SCHEMA_V1,
                                        NAXML_KEY_SCHEMA_ROOT,
                                        NAXML_KEY_SCHEMA_LIST,
                                        NULL,
@@ -135,7 +135,7 @@ static ExportFormatFn st_export_format_fn[] = {
                                        write_data_schema_v1,
                                        write_type_schema_v1 },
 
-       { NAXML_FORMAT_GCONF_SCHEMA_V2,
+       { FMA_XML_FORMAT_GCONF_SCHEMA_V2,
                                        NAXML_KEY_SCHEMA_ROOT,
                                        NAXML_KEY_SCHEMA_LIST,
                                        NULL,
@@ -143,7 +143,7 @@ static ExportFormatFn st_export_format_fn[] = {
                                        write_data_schema_v2,
                                        write_type_schema_v2 },
 
-       { NAXML_FORMAT_GCONF_ENTRY,
+       { FMA_XML_FORMAT_GCONF_ENTRY,
                                        NAXML_KEY_DUMP_ROOT,
                                        NAXML_KEY_DUMP_LIST,
                                        write_list_attribs_dump,
@@ -835,15 +835,15 @@ get_output_fname( const FMAObjectItem *item, const gchar *folder, const gchar *f
 
        item_id = fma_object_get_id( item );
 
-       if( !strcmp( format, NAXML_FORMAT_GCONF_SCHEMA_V1 )){
+       if( !strcmp( format, FMA_XML_FORMAT_GCONF_SCHEMA_V1 )){
                canonical_fname = g_strdup_printf( "config_%s", item_id );
                canonical_ext = g_strdup( "schemas" );
 
-       } else if( !strcmp( format, NAXML_FORMAT_GCONF_SCHEMA_V2 )){
+       } else if( !strcmp( format, FMA_XML_FORMAT_GCONF_SCHEMA_V2 )){
                canonical_fname = g_strdup_printf( "config-%s", item_id );
                canonical_ext = g_strdup( "schema" );
 
-       } else if( !strcmp( format, NAXML_FORMAT_GCONF_ENTRY )){
+       } else if( !strcmp( format, FMA_XML_FORMAT_GCONF_ENTRY )){
                canonical_fname = g_strdup_printf( "%s-%s", FMA_IS_OBJECT_ACTION( item ) ? "action" : "menu", 
item_id );
                canonical_ext = g_strdup( "xml" );
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/io-xml/naxml-formats.c b/src/io-xml/fma-xml-formats.c
similarity index 84%
rename from src/io-xml/naxml-formats.c
rename to src/io-xml/fma-xml-formats.c
index 0546cf0..cb50ff3 100644
--- a/src/io-xml/naxml-formats.c
+++ b/src/io-xml/fma-xml-formats.c
@@ -35,7 +35,7 @@
 #include <gtk/gtk.h>
 #include <libintl.h>
 
-#include "naxml-formats.h"
+#include "fma-xml-formats.h"
 
 typedef struct {
        gchar *format;
@@ -45,13 +45,13 @@ typedef struct {
 }
        NaxmlExportFormat;
 
-static NaxmlExportFormat naxml_formats[] = {
+static NaxmlExportFormat fma_xml_formats[] = {
 
        /* GCONF_SCHEMA_V1: a schema with owner, short and long descriptions;
         * each action has its own schema addressed by the id
         * (historical format up to v1.10.x serie)
         */
-       { NAXML_FORMAT_GCONF_SCHEMA_V1,
+       { FMA_XML_FORMAT_GCONF_SCHEMA_V1,
                        N_( "Export as a _full GConf schema file" ),
                        N_( "This used to be the historical export format.\n" \
                                "The exported schema file may later be imported via :\n" \
@@ -63,7 +63,7 @@ static NaxmlExportFormat naxml_formats[] = {
        /* GCONF_SCHEMA_V2: the lightest schema still compatible with gconftool-2 --install-schema-file
         * (no owner, no short nor long descriptions) - introduced in v 1.11
         */
-       { NAXML_FORMAT_GCONF_SCHEMA_V2,
+       { FMA_XML_FORMAT_GCONF_SCHEMA_V2,
                        N_( "Export as a _light GConf schema (v2) file" ),
                        N_( "This format has been introduced in v 1.11 serie.\n" \
                                "This is the lightest schema still compatible with GConf command-line tools, 
" \
@@ -78,7 +78,7 @@ static NaxmlExportFormat naxml_formats[] = {
        /* GCONF_ENTRY: not a schema, but a dump of the GConf entry
         * introduced in v 1.11
         */
-       { NAXML_FORMAT_GCONF_ENTRY,
+       { FMA_XML_FORMAT_GCONF_ENTRY,
                        N_( "Export as a GConf _dump file" ),
                        N_( "This format has been introduced in v 1.11 serie.\n" \
                                "Tough not backward compatible with FileManager-Actions " \
@@ -98,20 +98,20 @@ static void on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
 #endif
 
 /**
- * naxml_formats_get_formats:
+ * fma_xml_formats_get_formats:
  * @exporter: this #FMAIExporter provider.
  *
  * Returns: a #GList of the #FMAIExporterFormatv2 supported export formats.
  *
  * This list should be naxml_formats_free_formats() by the caller.
  *
  * Since: 3.2
  */
 GList *
-naxml_formats_get_formats( const FMAIExporter* exporter )
+fma_xml_formats_get_formats( const FMAIExporter* exporter )
 {
 #if 0
-       static const gchar *thisfn = "naxml_formats_get_formats";
+       static const gchar *thisfn = "fma_xml_formats_get_formats";
 #endif
        GList *str_list;
        FMAIExporterFormatv2 *str;
@@ -125,15 +125,15 @@ naxml_formats_get_formats( const FMAIExporter* exporter )
                width = height = 48;
        }
 
-       for( i = 0 ; naxml_formats[i].format ; ++i ){
+       for( i = 0 ; fma_xml_formats[i].format ; ++i ){
                str = g_new0( FMAIExporterFormatv2, 1 );
                str->version = 2;
                str->provider = FMA_IEXPORTER( exporter );
-               str->format = g_strdup( naxml_formats[i].format );
-               str->label = g_strdup( gettext( naxml_formats[i].label ));
-               str->description = g_strdup( gettext( naxml_formats[i].description ));
-               if( naxml_formats[i].image ){
-                       fname = g_strdup_printf( "%s/%s", PROVIDER_DATADIR, naxml_formats[i].image );
+               str->format = g_strdup( fma_xml_formats[i].format );
+               str->label = g_strdup( gettext( fma_xml_formats[i].label ));
+               str->description = g_strdup( gettext( fma_xml_formats[i].description ));
+               if( fma_xml_formats[i].image ){
+                       fname = g_strdup_printf( "%s/%s", PROVIDER_DATADIR, fma_xml_formats[i].image );
                        str->pixbuf = gdk_pixbuf_new_from_file_at_size( fname, width, height, NULL );
                        g_free( fname );
 #if 0
@@ -158,12 +158,12 @@ naxml_formats_get_formats( const FMAIExporter* exporter )
 static void
 on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
 {
-       g_debug( "naxml_formats_on_pixbuf_finalized: exporter=%p, pixbuf=%p", ( void * ) exporter, ( void * ) 
pixbuf );
+       g_debug( "fma_xml_formats_on_pixbuf_finalized: exporter=%p, pixbuf=%p", ( void * ) exporter, ( void * 
) pixbuf );
 }
 #endif
 
 /**
- * naxml_formats_free_formats:
+ * fma_xml_formats_free_formats:
  * @formats: a #GList to be freed.
  *
  * Releases the list of managed formats.
@@ -171,7 +171,7 @@ on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
  * Since: 3.2
  */
 void
-naxml_formats_free_formats( GList *formats )
+fma_xml_formats_free_formats( GList *formats )
 {
        GList *is;
        FMAIExporterFormatv2 *str;
@@ -98,20 +98,20 @@ static void on_pixbuf_finalized( const FMAIExporter* exporter, GObject *pixbuf )
  * Returns: a #GList of the #FMAIExporterFormatv2 supported export formats.
  *
- * This list should be naxml_formats_free_formats() by the caller.
+ * This list should be fma_xml_formats_free_formats() by the caller.
  *
  * Since: 3.2